@@ -1,3 +1,4 @@
+
 class CustomList(list):
     def __init__(self, _list):
         for i, val in enumerate(_list):
@@ -8,17 +9,16 @@ class CustomList(list):
 
         list.__init__(self, _list)
 
+
 class CustomDict(dict):
     def __init__(self, _dict):
-        dict.__init__(self, _dict)
-
         for key in list(_dict):
             if isinstance(_dict[key], list):
-                dict.__setitem__(self, key, CustomList(_dict[key]))
+                _dict[key] = CustomList(_dict[key])
             elif isinstance(_dict[key], dict):
-                dict.__setitem__(self, key, CustomDict(_dict[key]))
-            else:
-                dict.__setitem__(self, key, _dict[key])
+                _dict[key] = CustomDict(_dict[key])
+
+        dict.__init__(self, _dict)
 
     def __getattr__(self, name):  # CustomDict.a
         return dict.__getitem__(self, name)
@@ -27,6 +27,6 @@ class CustomDict(dict):
         return dict.__setitem__(self, name, value)
 
     def __delattr__(self, name):  # del CustomDict.a
-        popped = dict.__getitem__(key)
-        dict.__delitem__(self, key)
+        popped = dict.__getitem__(name)
+        dict.__delitem__(self, name)
         return popped
